@@ -1,4 +1,5 @@
 import gzip
+import base64
 from .rest import *
 from .dassana_env import *
 from abc import ABCMeta, abstractmethod
@@ -19,7 +20,10 @@ class Pipe(metaclass=ABCMeta):
         pass
 
     def flush(self):
-        return forward_logs(self.json_logs)
+        flush_res = forward_logs(self.json_logs, app_id=self.app_id)
+        self.json_logs = []
+        return flush_res
+        
 
 
 class CloudTrailPipe(Pipe):
@@ -317,8 +321,53 @@ class AzureActivityPipe(Pipe):
             self.json_logs.append(record)
 
 
-def DataPipe():
+class EKSPipe(Pipe):
+    def __init__(self):
+        super().__init__()
 
+    def push(self, content):
+        decoded_event = base64.b64decode(content)
+        decompressed_content = gzip.decompress(decoded_event)
+        decompressed_content = loads(decompressed_content)
+        cw_logs = decompressed_content["logEvents"]
+        for log in cw_logs:
+            try:
+                fmt_log = loads(log["message"])
+                fmt_log["timestamp"] = log["timestamp"]
+            except Exception:
+                fmt_log = log
+
+            self.json_logs.append(fmt_log)
+
+class ConfigSnapshotPipe(Pipe):
+    def __init__(self, app_id = ''):
+        super().__init__()
+        self.bytes_so_far = 0
+        self.app_id = app_id
+
+    def push(self, content):
+        self.json_logs.append(content)
+        self.bytes_so_far += len(dumps(content))
+        if self.bytes_so_far >= (0.1 * 1048576):
+            self.bytes_so_far = 0
+            return True
+        else:
+            return False
+
+class ConfigChangePipe(Pipe):
+    def __init__(self, app_id = ''):
+        super().__init__()
+        self.app_id = app_id
+
+    def push(self, content):
+        with gzip.GzipFile(fileobj=BytesIO(content), mode="rb") as decompress_stream:
+            data = load(decompress_stream)     
+            items = data['configurationItems']
+            for item in items:
+                self.json_logs.append(item)
+
+
+def DataPipe():
     pipe_selector = {
         "aws_cloudtrail": CloudTrailPipe,
         "aws_vpc_flow": VPCFlowPipe,
@@ -328,6 +377,15 @@ def DataPipe():
         "aws_route53_query": Route53QueryPipe,
         "aws_network_firewall": NetworkFirewallPipe,
         "azure_test": AzureActivityPipe,
+        "aws_eks": EKSPipe,
     }
-
     return pipe_selector[get_app_id()]()
+
+def ConfigPipe(app_id='aws_config', one_time=True):
+    if one_time:
+        return ConfigSnapshotPipe(app_id=app_id)
+    else: 
+        return ConfigChangePipe(app_id=app_id)
+
+
+    
